==> haskell-network-protocol-xmpp-0.5.2-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-protocol-xmpp
version:              0.5.2
visibility:           public
id:                   network-protocol-xmpp-0.5.2-HBPWlPZTLiR2Z3OVPfDEPf
key:                  network-protocol-xmpp-0.5.2-HBPWlPZTLiR2Z3OVPfDEPf
license:              GPL-3.0-only
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:
    John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>

stability:            experimental
homepage:             https://git.sr.ht/~singpolyma/network-protocol-xmpp
synopsis:             Client library for the XMPP protocol.
category:             Network
abi:                  692f50f8c39c1cd608cc672d58395a3d
exposed:              True
exposed-modules:      Network.Protocol.XMPP Network.Protocol.XMPP.Internal
hidden-modules:
    Network.Protocol.XMPP.Client
    Network.Protocol.XMPP.Client.Authentication
    Network.Protocol.XMPP.Client.Features
    Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
    Network.Protocol.XMPP.Handle Network.Protocol.XMPP.JID
    Network.Protocol.XMPP.Monad Network.Protocol.XMPP.Stanza
    Network.Protocol.XMPP.XML Network.Protocol.XMPP.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-protocol-xmpp
hs-libraries:         HSnetwork-protocol-xmpp-0.5.2-HBPWlPZTLiR2Z3OVPfDEPf
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    gnuidn-0.2.2-IHAkK19H4pZ6MGdalqyYN9
    gnutls-0.3.1-GeCONIUYfrHFLxYdcKd0Rw
    gsasl-0.3.7-5di2RX669526hFHZ9nNEon
    libxml-sax-0.7.6-HwBnkvybtGu4sa5CpUDnnV
    network-3.1.4.0-GAyMeTMiQBM1z6BFq5KYYA
    network-simple-0.4.5-7GYR8Do99T3DYYKdLLJeha text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock

haddock-html:         /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-protocol-xmpp-0.5.2-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-protocol-xmpp
version:              0.5.2
visibility:           public
id:                   network-protocol-xmpp-0.5.2-Ly91Aqw5bHR46uwpehBXmi
key:                  network-protocol-xmpp-0.5.2-Ly91Aqw5bHR46uwpehBXmi
license:              GPL-3.0-only
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:
    John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>

stability:            experimental
homepage:             https://git.sr.ht/~singpolyma/network-protocol-xmpp
synopsis:             Client library for the XMPP protocol.
category:             Network
abi:                  946964fd63661bbe0b32e831e87c3838
exposed:              True
exposed-modules:      Network.Protocol.XMPP Network.Protocol.XMPP.Internal
hidden-modules:
    Network.Protocol.XMPP.Client
    Network.Protocol.XMPP.Client.Authentication
    Network.Protocol.XMPP.Client.Features
    Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
    Network.Protocol.XMPP.Handle Network.Protocol.XMPP.JID
    Network.Protocol.XMPP.Monad Network.Protocol.XMPP.Stanza
    Network.Protocol.XMPP.XML Network.Protocol.XMPP.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-protocol-xmpp-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-protocol-xmpp
hs-libraries:         HSnetwork-protocol-xmpp-0.5.2-Ly91Aqw5bHR46uwpehBXmi
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    gnuidn-0.2.2-IHAkK19H4pZ6MGdalqyYN9
    gnutls-0.3.1-GeCONIUYfrHFLxYdcKd0Rw
    gsasl-0.3.7-5di2RX669526hFHZ9nNEon
    libxml-sax-0.7.6-2kDASUMMdZELGa4nEfhGgh
    network-3.1.4.0-4cEUA9pnnvEEvGlZk2FqT
    network-simple-0.4.5-1ngxISYkgsDDZ9m2RvQlwa text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:
    /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock

haddock-html:         /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
